@@ -312,11 +312,9 @@ def execute(commandLine):
     logging.debug("CMD: '{}'".format(commandLine))
     process = Popen(commandLine, shell=True, stdout=PIPE, stderr=PIPE)
     out = process.stdout.read().decode('utf-8', errors='ignore').strip()
-    out = out.replace("\r", "")
     out = str.join("", list([x for x in out if x in string.printable]))
     logging.debug("CMD: '{}' RESULT: {}".format(commandLine, out))
     error = process.stderr.read().decode('utf-8', errors='ignore').strip()
-    error = error.replace("\r", "")
     error = str.join("", list([x for x in error if x in string.printable]))
     if error and not out:
         process.kill()
@@ -359,30 +357,36 @@ def get_last_branch_changeSet(branch, numberOfChangets):
     output = execute(MoveToMainDirectory + TF_Branches_History.format(branch) + (
         "" if numberOfChangets == None else " /stopafter:{}".format(numberOfChangets)))
 
+    endline_char = detect_endline(output)
+
     changeSetList = []
 
-    output_list = [item for item in output.split("-" * 79 + '\n\n') if item]
-    logging.debug("output_list len: {}".format(len(output_list)))
-    
+    # output = output.replace("\r", "")
+    output_list = [item.lstrip() for item in output.split("-" * 79 + endline_char) if item]
+
+    idx = 0
+
     for changeset_raw in output_list:
         changeSetDict = {}
         itemsDict = {}
 
-        changeSetDict['branch'] = branch
+        changeSetDict['branch'] = 'branch'
         changeSetDict['items'] = itemsDict
 
-        changeset_info_items = changeset_raw.split("\n\n\n\n")
+        changeset_info_items = changeset_raw.split(endline_char * 2)
         changeset_items = list()
 
         for changeset_info_item in changeset_info_items:
             if any(changeset_info_item.startswith(keyword) for keyword in ['Changeset', 'User', 'Date']):
-                changeset_info_item = changeset_info_item.split('\n\n')
+                changeset_info_item = changeset_info_item.split(endline_char)
                 changeset_items.extend(changeset_info_item)
             else:
-                changeset_info_item = changeset_info_item.replace('\n\n', '\n')
+                changeset_info_item = changeset_info_item.replace(endline_char, '\n')
                 changeset_items.append(changeset_info_item)
 
+        idx += 1
         for changeset_item in changeset_items:
+
             for item in pattern.finditer(changeset_item):
                 propertyName, propertyData = item.groups()
                 propertyName = propertyName.lstrip().rstrip().replace(' ', '_').lower()
@@ -776,6 +780,16 @@ def wrap_shelvet_push_event(arr, info):
     return json.dumps(data)
 
 
+def detect_endline(text):
+    if text.find("\r\n") != -1:
+        return "\r\n"
+    if text.find("\r") != -1:
+        return "\r\r"
+    if text.find("\n\n") != -1:
+        return "\n\n"
+    return ""
+
+
 def to_iso(data):
     if isinstance(data, str):
         data = str.join("", list([x for x in data if x in string.printable]))
